@@ -6,20 +6,20 @@ setClass("STS", # space-time partial
 	stopifnot(min(ix) >= 1 && max(ix) <= length(object@sp))
 	ix = unique(object@index[,2]) # time
 	stopifnot(min(ix) >= 1 && max(ix) <= nrow(object@time))
-    return(TRUE)
+	return(TRUE)
   }
 )
 
 setClass("STSDF", # space-time partial data frame
   representation("STS", data = "data.frame"),
   validity = function(object) {
-    stopifnot(nrow(object@index) == nrow(object@data))
-    stopifnot(ncol(object@index) == 2)
-	ix = unique(object@index[,1]) # space
-	stopifnot(min(ix) >= 1 && max(ix) <= length(object@sp))
-	ix = unique(object@index[,2]) # time
-	stopifnot(min(ix) >= 1 && max(ix) <= nrow(object@time))
-    .checkAttrIsUnique(object@sp, object@time, object@data)
-    return(TRUE)
+	stopifnot(nrow(object@index) == nrow(object@data))
+    #stopifnot(ncol(object@index) == 2)
+	#ix = unique(object@index[,1]) # space
+	#stopifnot(min(ix) >= 1 && max(ix) <= length(object@sp))
+	#ix = unique(object@index[,2]) # time
+	#stopifnot(min(ix) >= 1 && max(ix) <= nrow(object@time))
+    #.checkAttrIsUnique(object@sp, object@time, object@data)
+	return(TRUE)
   }
 )
